gatenlp.gate_interaction module — GATE NLP library (gatenlp) documentation

# gatenlp.gate_interaction module

Support for interacting between a GATE (java) process and a gatenlp (Python) process.

class `gatenlp.gate_interaction.` `DefaultPr`

  Bases: `object`

  `finish`(**kwargs)
  `reduce`(resultlist, **kwargs)
  `start`(**kwargs)

`gatenlp.gate_interaction.` `get_arguments`(from_main=False)

`gatenlp.gate_interaction.` `interact`(args=None)

  Starts and handles the interaction with a GATE python plugin process. This will get started by the GATE plugin if the interaction uses pipes, but can also be started separately for http/websockets.

  This MUST be called in the user’s python file! The python file should also have one class or function decorated with the @gatenlp.PR decorator to identify it as the processing resource to the system.

  Returns